Index: /trunk/src/VBox/Devices/Network/DevPCNet.cpp
===================================================================
--- /trunk/src/VBox/Devices/Network/DevPCNet.cpp	(revision 76059)
+++ /trunk/src/VBox/Devices/Network/DevPCNet.cpp	(revision 76060)
@@ -7,5 +7,6 @@
  *      AMD Publication# 19436  Rev:E  Amendment/0  Issue Date: June 2000
  * and
- *      todo
+ *      AMD Am79C973/Am79C975 PCnet-FAST III Single-Chip 10/100 Mbps PCI Ethernet Controller datasheet
+ *      AMD publication# 20510  Rev:E  Amendment/0  Issue Date: August 2000
  */
 
@@ -24,5 +25,5 @@
  * This code is based on:
  *
  * AMD PC-Net II (Am79C970A) emulation
  *
  * Copyright (c) 2004 Antony T Curtis
@@ -468,5 +469,5 @@
 } PCNETSTATE;
 //AssertCompileMemberAlignment(PCNETSTATE, StatReceiveBytes, 8);
 /** Pointer to a PC-Net state structure. */
 typedef PCNETSTATE *PPCNETSTATE;
 
@@ -3877,5 +3878,5 @@
 
 /**
- * @callback_method_impl{FNPCIIOREGIONMAP, For the PC-NET I/O Ports.}
+ * @callback_method_impl{FNPCIIOREGIONMAP, For the PCnet I/O Ports.}
  */
 static DECLCALLBACK(int) pcnetIOPortMap(PPDMDEVINS pDevIns, PPDMPCIDEV pPciDev, uint32_t iRegion,
@@ -3928,5 +3929,5 @@
 
 /**
- * @callback_method_impl{FNPCIIOREGIONMAP, For the PC-Net MMIO region.}
+ * @callback_method_impl{FNPCIIOREGIONMAP, For the PCnet MMIO region.}
  */
 static DECLCALLBACK(int) pcnetMMIOMap(PPDMDEVINS pDevIns, PPDMPCIDEV pPciDev, uint32_t iRegion,
@@ -4446,5 +4447,5 @@
  *
  * @returns VBox status code.
  * @param   pThis           The PC-Net instance data.
  */
 static int pcnetCanReceive(PPCNETSTATE pThis)
@@ -5232,5 +5233,5 @@
 #endif
     /* pszDescription */
-    "AMD PC-Net II Ethernet controller.\n",
+    "AMD PCnet Ethernet controller.\n",
     /* fFlags */
 #ifdef PCNET_GC_ENABLED
@@ -24,5 +25,5 @@
  * This code is based on:
  *
- * AMD PC-Net II (Am79C970A) emulation
+ * AMD PCnet-PCI II (Am79C970A) emulation
  *
  * Copyright (c) 2004 Antony T Curtis
@@ -468,5 +469,5 @@
 } PCNETSTATE;
 //AssertCompileMemberAlignment(PCNETSTATE, StatReceiveBytes, 8);
-/** Pointer to a PC-Net state structure. */
+/** Pointer to a PCnet state structure. */
 typedef PCNETSTATE *PPCNETSTATE;
 
@@ -4446,5 +4447,5 @@
  *
  * @returns VBox status code.
- * @param   pThis           The PC-Net instance data.
+ * @param   pThis           The PCnet instance data.
  */
 static int pcnetCanReceive(PPCNETSTATE pThis)
